@@ -239,6 +239,11 @@ public final class JoGLCanvas implements Canvas, GLEventListener {
         if (isOffscreen) {
             ((GLPbuffer) autoDrawable).destroy();
         }
+        try {
+            canvasAnimator.finalize();
+        } catch (Throwable e) {
+            // TODO: handle exception
+        }
     }
 
     /**
@@ -319,15 +324,19 @@ public final class JoGLCanvas implements Canvas, GLEventListener {
         private final Semaphore semaphore = new Semaphore(1);
         private final Thread thread;
         private final GLAutoDrawable autoDrawable;
+        private boolean running = true;
 
         public CanvasAnimator(GLAutoDrawable autoDrawable) {
             this.autoDrawable = autoDrawable;
             this.thread = new Thread(this);
             thread.start();
+            //System.err.println("[DEBUG] nb threads = "+Thread.activeCount());
         }
 
         @Override
         public void finalize() throws Throwable {
+            running = false;
+            semaphore.release();
             super.finalize();
         }
 
@@ -345,12 +354,14 @@ public final class JoGLCanvas implements Canvas, GLEventListener {
 
         @Override
         public void run() {
-            for (;;) {
+            while(running) {
                 try {
                     semaphore.acquire();
                     semaphore.drainPermits();
                     autoDrawable.display();
                 } catch (InterruptedException e) {
+                    Thread.currentThread().interrupt();
+                    break;
                 }
             }
         }
