@@ -188,7 +188,7 @@ public class RulerDrawer {
 
             Appearance appearance = new Appearance();
             appearance.setLineColor(rulerModel.getColor());
-            appearance.setLineWidth(1);
+            appearance.setLineWidth((float) rulerModel.getLineWidth());
 
             drawingTools.getTransformationManager().useWindowCoordinate();
             try {
@@ -393,8 +393,9 @@ public class RulerDrawer {
                 usedDirection = direction;
             }
 
-            double ratioX = sprite.getDataProvider().getTextureSize().width / Math.abs(usedDirection.getX());
-            double ratioY = sprite.getDataProvider().getTextureSize().height / Math.abs(usedDirection.getY());
+            /* +1 is used to have a space between the tick and its label */
+            double ratioX = sprite.getDataProvider().getTextureSize().width / Math.abs(usedDirection.getX()) + 1;
+            double ratioY = sprite.getDataProvider().getTextureSize().height / Math.abs(usedDirection.getY()) + 1;
             double ratio = Math.min(ratioY, ratioX) / 2;
             return usedDirection.times(ratio);
         }
